#
# spec file for package python-lexicon
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-lexicon
VCS: https://src.suse.de/SLFO-pool/python-lexicon#f2d070937b47384e35306f350238b7e5093bdc341b7a2c8b0802a73e0f3c4756
Version:        2.0.1
Release:        160000.2.4
Summary:        Python dict subclass(es) with aliasing and attribute access
License:        BSD-2-Clause
URL:            https://github.com/bitprophet/lexicon
Source:         https://files.pythonhosted.org/packages/source/l/lexicon/lexicon-%{version}.tar.gz
# PATCH-FIX-UPSTREAM (sort of) Not in the sdist, but on GitHub
Patch0:         add-pytest-ini.patch
# PATCH-FIX-OPENSUSE Support pytest >= 8
Patch1:         support-pytest-8.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# Completely different pkg but same namespece in sitelib folder
Conflicts:      python-dns-lexicon
BuildArch:      noarch
# SECTION tests
BuildRequires:  %{python_module pytest-relaxed}
# /SECTION tests
%python_subpackages

%description
Lexicon is a collection of dict subclasses:

* AliasDict, a dictionary supporting both simple and complex key aliasing
* AttributeDict, supporting attribute read and write access
* Lexicon, a subclass of both of the above which exhibits both sets of behavior

%prep
%autosetup -p1 -n lexicon-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/lexicon
%{python_sitelib}/lexicon-%{version}.dist-info

%changelog
* Tue May 14 2024 steven.kowalik@suse.com
- Switch to pyproject and autosetup macros.
- Add patch support-pytest-8.patch:
  * Use new "setup_method" to support pytest >= 8.
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Thu Mar 10 2022 steven.kowalik@suse.com
- pytest-relaxed now supports pytest 6, so test on all python versions.
* Mon Dec 13 2021 code@bnavigator.de
- Don't test on python310 because of pytest-relaxed not supporting
  Pytest 6 -- gh#bitprophet/pytest-relaxed#12
* Fri Sep 17 2021 steven.kowalik@suse.com
- Update to 2.0.1:
  * Fix up some project metadata.
  * Dropped support for Python <3.6
  * Added a _version submodule and imported its dunder-attributes into
    the top level module
  * Migrated CI to CircleCI (from Travis)
  * Migrated tests to pytest(-relaxed)
  * Moved changelog to stub Sphinx project for Releases plugin
  * Changed README to ReStructured Text (from Markdown)
- Dropped patch add_test_init.patch, no longer required.
- Added patch add-pytest-ini.patch:
  * Add the pytest.ini file that isn't included in the source distribution
    so the testsuite works.
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Mon Apr 23 2018 tchvatal@suse.com
- Conflict with python-dns-lexicon that provides same namespace
* Sun Mar  4 2018 jengelh@inai.de
- Update descriptions.
* Sat Mar  3 2018 sebix+novell.com@sebix.at
- initial package for version 1.0.0
- add add_test_init.patch to fix execution of tests
